@@ -56,6 +56,14 @@
 #define CASE_INDENT (INDENT_SIZE)
 #define LABEL_INDENT (INDENT_SIZE)
 
+static gboolean
+is_closing_bracket(gchar ch)
+{
+	if (ch == ')' || ch == '}' || ch == ']')
+		return TRUE;
+	return FALSE;
+}
+
 static gboolean
 iter_is_newline (IAnjutaIterable *iter, gchar ch)
 {
@@ -1173,16 +1181,16 @@ insert_editor_blocked (IAnjutaEditor* editor,
                        gchar* text,
                        IndentCPlugin* plugin)
 {
-	g_signal_handlers_block_by_func (editor, cpp_indentation, plugin);
+	g_signal_handlers_block_by_func (editor, cpp_java_indentation_char_added, plugin);
 	ianjuta_editor_insert (editor, iter, text, -1, NULL);
-	g_signal_handlers_unblock_by_func (editor, cpp_indentation, plugin);
+	g_signal_handlers_unblock_by_func (editor, cpp_java_indentation_char_added, plugin);
 }
 
 void
-cpp_indentation (IAnjutaEditor *editor,
-                 IAnjutaIterable *insert_pos,
-                 gchar ch,
-                 IndentCPlugin *plugin)
+cpp_java_indentation_char_added (IAnjutaEditor *editor,
+                                 IAnjutaIterable *insert_pos,
+                                 gchar ch,
+                                 IndentCPlugin *plugin)
 {
 	IAnjutaEditorAttribute attrib;
 	IAnjutaIterable *iter;
@@ -1259,15 +1267,25 @@ cpp_indentation (IAnjutaEditor *editor,
 	{
 		if (ch == '[' || ch == '(')
 		            {
-						gchar *prev_char;
-						IAnjutaIterable *previous;
+						gchar *prev_char, *next_char;
+						IAnjutaIterable *previous, *next, *next_end;
 
 						previous = ianjuta_iterable_clone (iter, NULL);
 						ianjuta_iterable_previous (previous, NULL);
 						prev_char = ianjuta_editor_get_text (editor, previous, iter, NULL);
 
-						/* If the previous char is a ' we don't have to autocomplete */
-						if (*prev_char != '\'')
+						next = ianjuta_iterable_clone (iter, NULL);
+						ianjuta_iterable_next (next, NULL);
+						next_end = ianjuta_iterable_clone (next, NULL);
+						ianjuta_iterable_next (next_end, NULL);
+						next_char = ianjuta_editor_get_text (editor, next, next_end, NULL);
+
+						/* If the previous char is a ' we don't have to autocomplete,
+						   also we only autocomplete if the next character is white-space
+						   a closing bracket, "," or ";" */
+						if (*prev_char != '\'' &&
+						    (g_ascii_isspace(*next_char) || is_closing_bracket (*next_char) ||
+							 *next_char == ',' || *next_char == ';'|| *next_char == '\0'))
 						{
 							ianjuta_document_begin_undo_action (IANJUTA_DOCUMENT (editor), NULL);
 							ianjuta_iterable_next (iter, NULL);
@@ -1335,6 +1353,46 @@ cpp_indentation (IAnjutaEditor *editor,
 	g_object_unref (iter);
 }
 
+static void
+erase_editor_blocked (IAnjutaEditor* editor,
+                      IAnjutaIterable* start,
+                      IAnjutaIterable* end,
+                      IndentCPlugin* plugin)
+{
+	g_signal_handlers_block_by_func (editor, cpp_java_indentation_changed, plugin);
+	ianjuta_editor_erase (editor, start, end, NULL);
+	g_signal_handlers_unblock_by_func (editor, cpp_java_indentation_changed, plugin);
+}
+
+void
+cpp_java_indentation_changed (IAnjutaEditor *editor,
+                              IAnjutaIterable *position,
+                              gboolean added,
+                              gint length,
+                              gint lines,
+                              const gchar *text,
+                              IndentCPlugin* plugin)
+{
+	/* If autoindent is enabled*/
+	if (plugin->smart_indentation)
+	{
+		if (g_settings_get_boolean (plugin->settings, PREF_BRACE_AUTOCOMPLETION))
+		{
+			if (!added && length == 1 && (*text == '[' || *text == '('))
+			{
+				IAnjutaIterable *next;
+				gchar *next_char;
+
+				next = ianjuta_iterable_clone (position, NULL);
+				ianjuta_iterable_next (next, NULL);
+				next_char = ianjuta_editor_get_text (editor, position, next, NULL);
+				if ((*text == '[' && *next_char == ']') || (*text == '(' && *next_char == ')'))
+					erase_editor_blocked (editor, position, next, plugin);
+			}
+		}
+	}
+}
+
 void
 cpp_auto_indentation (IAnjutaEditor *editor,
                       IndentCPlugin *lang_plugin,
@@ -1386,13 +1444,3 @@ cpp_auto_indentation (IAnjutaEditor *editor,
 	}
 	ianjuta_document_end_undo_action (IANJUTA_DOCUMENT(editor), NULL);
 }
-
-
-void
-java_indentation (IAnjutaEditor *editor,
-                  IAnjutaIterable *insert_pos,
-                  gchar ch,
-                  IndentCPlugin *plugin)
-{
-	cpp_indentation (editor, insert_pos, ch, plugin);
-}
