@@ -349,19 +349,16 @@ install_support (IndentCPlugin *lang_plugin)
     if (lang_plugin->current_language &&
         (g_str_equal (lang_plugin->current_language, "C")
         || g_str_equal (lang_plugin->current_language, "C++")
-        || g_str_equal (lang_plugin->current_language, "Vala")))
+        || g_str_equal (lang_plugin->current_language, "Vala")
+        || g_str_equal (lang_plugin->current_language, "Java")))
     {
         g_signal_connect (lang_plugin->current_editor,
                           "char-added",
-                          G_CALLBACK (cpp_indentation),
+                          G_CALLBACK (cpp_java_indentation_char_added),
                           lang_plugin);
-    }
-    else if (lang_plugin->current_language &&
-        (g_str_equal (lang_plugin->current_language, "Java")))
-    {
         g_signal_connect (lang_plugin->current_editor,
-                          "char-added",
-                          G_CALLBACK (java_indentation),
+                          "changed",
+                          G_CALLBACK (cpp_java_indentation_changed),
                           lang_plugin);
     }
     else
@@ -382,17 +379,14 @@ uninstall_support (IndentCPlugin *lang_plugin)
     if (lang_plugin->current_language &&
         (g_str_equal (lang_plugin->current_language, "C")
         || g_str_equal (lang_plugin->current_language, "C++")
-        || g_str_equal (lang_plugin->current_language, "Vala")))
+        || g_str_equal (lang_plugin->current_language, "Vala")
+        || g_str_equal (lang_plugin->current_language, "Java")))
     {
         g_signal_handlers_disconnect_by_func (lang_plugin->current_editor,
-                                    G_CALLBACK (cpp_indentation),
+                                    G_CALLBACK (cpp_java_indentation_char_added),
                                     lang_plugin);
-    }
-    else if (lang_plugin->current_language &&
-        (g_str_equal (lang_plugin->current_language, "Java")))
-    {
-        g_signal_handlers_disconnect_by_func (lang_plugin->current_editor,
-                                    G_CALLBACK (java_indentation),
+		g_signal_handlers_disconnect_by_func (lang_plugin->current_editor,
+                                    G_CALLBACK (cpp_java_indentation_changed),
                                     lang_plugin);
     }
     
